==> nextcloud-28.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/ca.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Equips",
    "Teams' files" : "Fitxers dels equips",
    "Select team to filter by" : "Seleccioneu l'equip que voleu filtrar",
    "No teams found" : "No s'ha trobat cap equip",
    "Please select teams to filter by" : "Seleccioneu els equips que voleu filtrar",
    "No files found for the selected teams" : "No s'ha trobat cap fitxer per als equips seleccionats",
    "You created the team {circle}" : "Heu creat l'equip {circle}",
    "{author} created the team {circle}" : "{author} ha creat l'equip {circle}",
    "You deleted {circle}" : "Heu suprimit {circle}",
    "{author} deleted {circle}" : "{author} ha suprimit {circle}",
    "You made {member} join {circle}" : "Heu fet que {member} s'uneixi a {circle}",
    "{author} made {member} join {circle}" : "{author} ha fet que {member} s'uneixi a {circle}",
    "You added team {member} as member to {circle}" : "Heu afegit l'equip {member} com a membre de {circle}",
    "{author} added team {member} has been added as member to {circle}" : "{author} ha afegit l'equip {member} com a membre de {circle}",
    "You made {member} leave {circle}" : "Heu fet que {member} abandoni {circle}",
    "{author} made {member} leave {circle}" : "{author} ha fet que {member} abandoni {circle}",
    "You removed {member} leave {circle}" : "Heu suprimit {member} de {circle}",
    "You joined {circle}" : "Us heu unit a {circle}",
    "{member} joined {circle}" : "{member} s'ha unit a {circle}",
    "You accepted the invitation to join {circle}" : "Heu acceptat la invitació per a unir-vos a {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} ha acceptat la invitació per a unir-se a {circle}",
    "You added {member} as member to {circle}" : "Heu afegit {member} com a membre del cercle {circle}",
    "You have been added as member to {circle} by {author}" : "{author} us ha afegit com a membre del cercle {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} ha afegit {membre} com a membre del cercle {circle}",
    "You added {external} to {circle}" : "Heu afegit {external} a {circle}",
    "{external} has been added to {circle} by {author}" : "{author} ha afegit {external} a {circle}",
    "You accepted {member}'s request to join {circle}" : "Heu acceptat la sol·licitud del membre {member} per a unir-se a {circle}",
    "Your request to join {circle} has been accepted by {author}" : "{author} ha acceptat la sol·licitud per a unir-vos a {circle}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} ha acceptat la sol·licitud del membre {member} per a unir-se a {circle}",
    "You left {circle}" : "Heu sortit del cercle {circle}",
    "{member} left {circle}" : "{member} ha sortit del cercle {circle}",
    "You declined the invitation to join {circle}" : "Heu rebutjat la invitació per a unir-vos a {circle}",
    "{member} declined an invitation to join {circle}" : "{member} ha rebutjat la invitació per a unir-se a {circle}",
    "You cancelled your request to join {circle}" : "Heu cancel·lat la sol·licitud per a unir-vos a {circle}",
    "{member} cancelled a request to join {circle}" : "{member} ha cancel·lat una sol·licitud per a unir-se a {circle}",
    "You removed {member} from {circle}" : "Heu suprimit {member} del cercle {circle}",
    "You have been removed from {circle} by {author}" : "{author} us ha suprimit del cercle {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} ha suprimit {member} del cercle {circle}",
    "You removed {external} from {circle}" : "Heu suprimit {external} del cercle {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} ha suprimit {external} del cercle {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Heu cancel·lat la invitació del membre {member} per a unir-vos a {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} ha cancel·lat la invitació per a unir-vos a {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} ha cancel·lat la invitació del membre {member} per a unir-se a {circle}",
    "You dismissed {member}'s request to join {circle}" : "Heu descartat la sol·licitud del membre {member} per a unir-se a {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "{author} ha descartat la sol·licitud per a unir-vos a {circle}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} ha descartat la sol·licitud del membre {member} per a unir-se a {circle}",
    "You invited {member} to join {circle}" : "Heu convidat {member} a unir-se a {circle}",
    "You have been invited to join {circle} by {author}" : "{author} us ha convidat a unir-vos a {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} ha convidat {member} a unir-se a {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "Heu canviat el nivell del membre {member} a {circle} a %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} ha canviat el vostre nivell a {circle} a %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} ha canviat el nivell del membre {member} a {circle} a %1$s",
    "You sent a request to join {circle}" : "Heu enviat una sol·licitud per a unir-vos a {circle}",
    "{member} sent a request to join {circle}" : "{member} ha enviat una sol·licitud per a unir-se a {circle}",
    "You are the new owner of {circle}" : "Ara teniu la propietat del cercle {circle}",
    "{member} is the new owner of {circle}" : "{member} ara té la propietat del cercle {circle}",
    "On events happening in a <strong>team</strong> of which you are a member" : "Quan es produeixin esdeveniments en un <strong>equip</strong> del qual sigueu membre",
    "Any important event in a <strong>team</strong> you are moderating" : "Quan es produeixi qualsevol esdeveniment important en un <strong>equip</strong> que modereu",
    "On global events happening in any <strong>team</strong>" : "Quan es produeixin esdeveniments globals en qualsevol <strong>equip</strong>",
    "Shared to Circles" : "Compartits en cercles",
    "Single" : "Individual",
    "Personal" : "Personal",
    "System" : "Sistema",
    "Visible" : "Visible",
    "Open" : "Obert",
    "Invite" : "Invitació",
    "Join request" : "Sol·licitud per a unir-s'hi",
    "Friends" : "Amics",
    "Password protected" : "Protegit amb contrasenya",
    "No Owner" : "Sense propietari",
    "Hidden" : "Ocult",
    "Backend" : "Rerefons",
    "Local" : "Local",
    "Root" : "Arrel",
    "Team invite" : "Invitació a l'equip",
    "Federated" : "Federat",
    "Mount point" : "Punt de muntatge",
    "Nextcloud Account" : "Compte del Nextcloud",
    "Nextcloud Group" : "Grup del Nextcloud",
    "Email address" : "Adreça electrònica",
    "Contact" : "Contacte",
    "Circle" : "Cercle",
    "Nextcloud App" : "Aplicació del Nextcloud",
    "Member" : "Membre",
    "Moderator" : "Moderació",
    "Admin" : "Administració",
    "Owner" : "Propietat",
    "%s shared »%s« with you." : "%s ha compartit «%s» amb vós.",
    "%s shared »%s« with \"%s\"." : "%s ha compartit «%s» amb «%s».",
    "%s on %s" : "%s a %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s ha compartit «%2$s» amb vós.\nJa hauríeu d'haver rebut un altre correu electrònic amb un enllaç per a accedir-hi.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s ha compartit «%2$s» amb vós. Ja hauríeu d'haver rebut un altre correu electrònic amb un enllaç per a accedir-hi.",
    "Password to access »%1$s« shared to you by %2$s" : "%2$s ha compartit amb vós la contrasenya per a accedir a «%1$s»",
    "Password to access »%s«" : "Contrasenya per a accedir a «%s»",
    "It is protected with the following password:" : "Està protegit amb la contrasenya següent:",
    "%1$s via %2$s" : "%1$s mitjançant %2$s",
    "Click the button below to open it." : "Feu clic en el botó següent per a obrir-lo.",
    "Open »%s«" : "Obre «%s»",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s ha compartit diversos fitxers amb vós.\nJa hauríeu d'haver rebut un altre correu electrònic amb un enllaç per a accedir-hi.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s ha compartit diversos fitxers amb vós. Ja hauríeu d'haver rebut un altre correu electrònic amb un enllaç per a accedir-hi.",
    "Password to access files shared to you by %1$s" : "Contrasenya per a accedir als fitxers que %1$s ha compartit amb vós",
    "Password to access files" : "Contrasenya per a accedir als fitxers",
    "%s shared multiple files with \"%s\"." : "%s ha compartit diversos fitxers amb «%s».",
    "%s shared multiple files with you." : "%s ha compartit diversos fitxers amb vós.",
    "Boot up" : "Engegada",
    "Nextcloud Initialization" : "Inicialització del Nextcloud",
    "Circles App Initialization" : "Inicialització de l'aplicació Cercles",
    "Fresh installation status" : "Estat d'instal·lació nou",
    "Building Local Database" : "S'està creant la base de dades local",
    "Testing Basic Circle Creation" : "S'està provant la creació d'un cercle bàsic",
    "Adding local users and moderators" : "S'estan afegint usuaris i moderadors locals",
    "Show all teams" : "Mostra tots els equips",
    "Create a new team" : "Crea un equip nou",
    "Files" : "Fitxers",
    "This feature is not available for personal circles" : "Aquesta característica no està disponible per als cercles personals",
    "The team is not federated" : "L'equip no està federat",
    "You cannot join this team" : "No us podeu unir a aquest equip",
    "This member is not a moderator" : "Aquest membre no té permisos de moderació",
    "Insufficient privileges" : "Privilegis insuficients",
    "This member does not exist" : "Aquest membre no existeix",
    "This member is the owner of the team" : "Aquest membre té la propietat de l'equip",
    "Level cannot be changed for this type of member" : "No es pot canviar el nivell per a aquest tipus de membre",
    "You are already a member of this circle" : "Ja sou membre d'aquest cercle",
    "You have been blocked from this circle" : "Se us ha blocat d'aquest cercle",
    "The account is already a member of this circle" : "El compte ja és membre d'aquest cercle",
    "The account has already been invited into this circle" : "El compte ja ha rebut una invitació per a aquest cercle",
    "%s (Team owned by %s)" : "%s (equip propietat de %s)",
    "You are now a member of the Circle \"%2$s\"" : "Ara sou membre del cercle «%2$s»",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "%1$s us ha convidat al cercle «%2$s»",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s ha enviat una sol·licitud per a ser membre del cercle «%2$s»",
    "Accept" : "Accepta",
    "Refuse" : "Rebutja",
    "Leave the circle" : "Surt del cercle",
    "%s" : "%s",
    "Personal team" : "Equip personal",
    "%s owned by %s" : "%s propietat de %s",
    "You have no permission to create a new team" : "No teniu permís per a crear un equip nou",
    "%s shared a file with \"%s\"." : "%s ha compartit un fitxer amb «%s».",
    "%s shared a file with you." : "%s ha compartit un fitxer amb vós.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s ha compartit contingut amb vós.\nJa hauríeu d'haver rebut un altre correu electrònic amb un enllaç per a accedir-hi.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s ha compartit contingut amb vós. Ja hauríeu d'haver rebut un altre correu electrònic amb un enllaç per a accedir-hi.",
    "Password to access content shared with you by %1$s" : "Contrasenya per a accedir al contingut que %1$s ha compartit amb vós",
    "Password to access content" : "Contrasenya per a accedir al contingut",
    "This item is already shared with this team" : "Aquest element ja està compartit amb aquest equip",
    "Bring cloud-users closer together." : "Acosteu els usuaris del núvol.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Els equips permeten que les persones creïn els seus propis grups de persones, companys i amics.\nQualsevol altra aplicació pot utilitzar aquests grups de persones per a compartir contingut.",
    "No files in here" : "No hi ha cap fitxer aquí",
    "No entries found in this folder" : "No s'ha trobat cap entrada en aquesta carpeta",
    "Name" : "Nom",
    "Size" : "Mida",
    "Modified" : "Data de modificació",
    "Circles" : "Cercles",
    "Circles' files" : "Fitxers de cercles",
    "Select circles to filter by" : "Seleccioneu els cercles pels quals voleu filtrar",
    "No circles found" : "No s'ha trobat cap cercle",
    "Please select circles to filter by" : "Seleccioneu els cercles pels quals voleu filtrar",
    "No files found for the selected circles" : "No s'ha trobat cap fitxer per als cercles seleccionats",
    "You created the circle {circle}" : "Heu creat el cercle {circle}",
    "{author} created the circle {circle}" : "{author} ha creat el cercle {circle}",
    "You added circle {member} as member to {circle}" : "Heu afegit el cercle {member} com a membre de {circle}",
    "{author} added circle {member} has been added as member to {circle}" : "{author} ha afegit el cercle {member} com a membre de {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Quan es produeixin esdeveniments en un <strong>cercle</strong> del qual sigueu membre",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Quan es produeixi qualsevol esdeveniment important en un <strong>cercle</strong> que modereu",
    "On global events happening in any <strong>Circle</strong>" : "Quan es produeixin esdeveniments globals en qualsevol <strong>cercle</strong>",
    "Join Request" : "Sol·licitud per a unir-s'hi",
    "Password Protected" : "Protegit amb contrasenya",
    "Circle Invite" : "Invitació al cercle",
    "Email Address" : "Adreça electrònica",
    "Initialisation Nextcloud" : "Inicialització del Nextcloud",
    "Initialisation Circles App" : "Inicialització de l’aplicació Cercles",
    "Circle not found" : "No s'ha trobat el cercle",
    "Circle not found " : "No s'ha trobat el cercle ",
    "This account is already a member of the circle" : "Aquest compte ja és membre del cercle",
    "Federated link not found" : "No s'ha trobat l'enllaç federat",
    "The circle is not federated" : "El cercle no és federat",
    "You cannot join this circle" : "No podeu unir-vos a aquest cercle",
    "This member is the owner of the circle" : "Aquest membre té la propietat del cercle",
    "%s (Circle owned by %s)" : "%s (cercle propietat de %s)",
    "Personal Circle" : "Cercle personal",
    "You need a specify a type of circle" : "Heu d'especificar un tipus de cercle",
    "A circle with that name exists" : "Ja existeix un cercle amb aquest nom",
    "This member is not the owner of the circle" : "Aquest membre no té la propietat del cercle",
    "This member is not an admin of the circle" : "Aquest membre no té permisos d'administració d'aquest cercle",
    "Group contains too many members" : "El grup té massa membres",
    "This group does not exist" : "Aquest grup no existeix",
    "This group is already linked to the circle" : "Aquest grup ja està enllaçat al cercle",
    "You cannot edit level in a personal circle" : "No podeu editar el nivell en un cercle personal",
    "Group cannot be set as owner of a circle" : "No es pot assignar la propietat d'un cercle a un grup",
    "now" : "ara",
    "This account does not exist" : "Aquest compte no existeix",
    "Email format is not valid" : "El format de l'adreça electrònica no és vàlid",
    "This contact is not available" : "Aquest contacte no està disponible",
    "You have no permission to create a new circle" : "No teniu permís per a crear un cercle nou",
    "This item is already shared with this circle" : "Aquest element ja està compartit amb aquest cercle",
    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Els cercles permeten que les persones creïn els seus propis grups de persones, companys i amics.\nQualsevol altra aplicació pot utilitzar aquests grups de persones (o «cercles») per a compartir contingut."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/ca.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Equips",
    "You created the team {circle}" : "Heu creat l'equip {circle}",
    "{author} created the team {circle}" : "{author} ha creat l'equip {circle}",
    "You deleted {circle}" : "Heu suprimit {circle}",
    "{author} deleted {circle}" : "{author} ha suprimit {circle}",
    "You made {member} join {circle}" : "Heu fet que {member} s'uneixi a {circle}",
    "{author} made {member} join {circle}" : "{author} ha fet que {member} s'uneixi a {circle}",
    "You added team {member} as member to {circle}" : "Heu afegit l'equip {member} com a membre de {circle}",
    "{author} added team {member} as member to {circle}" : "{author} ha afegit l'equip {member} com a membre a {circle}",
    "You made {member} leave {circle}" : "Heu fet que {member} abandoni {circle}",
    "{author} made {member} leave {circle}" : "{author} ha fet que {member} abandoni {circle}",
    "You removed {member} from {circle}" : "Heu suprimit {member} del cercle {circle}",
    "{author} removed {member} from {circle}" : "{author} ha eliminat {member} de {circle}",
    "You joined {circle}" : "Us heu unit a {circle}",
    "{member} joined {circle}" : "{member} s'ha unit a {circle}",
    "You accepted the invitation to join {circle}" : "Heu acceptat la invitació per a unir-vos a {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} ha acceptat la invitació per a unir-se a {circle}",
    "You added {member} as member to {circle}" : "Heu afegit {member} com a membre del cercle {circle}",
    "You have been added as member to {circle} by {author}" : "{author} us ha afegit com a membre del cercle {circle}",
    "{member} has been added as member to {circle} by {author}" : "{member} ha estat afegit com a membre a {circle} per {author}",
    "You added {external} to {circle}" : "Heu afegit {external} a {circle}",
    "{external} has been added to {circle} by {author}" : "{author} ha afegit {external} a {circle}",
    "You accepted {member}'s request to join {circle}" : "Heu acceptat la sol·licitud del membre {member} per a unir-se a {circle}",
    "Your request to join {circle} has been accepted by {author}" : "{author} ha acceptat la sol·licitud per a unir-vos a {circle}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} ha acceptat la sol·licitud del membre {member} per a unir-se a {circle}",
    "You left {circle}" : "Heu sortit del cercle {circle}",
    "{member} left {circle}" : "{member} ha sortit del cercle {circle}",
    "You declined the invitation to join {circle}" : "Heu rebutjat la invitació per a unir-vos a {circle}",
    "{member} declined an invitation to join {circle}" : "{member} ha rebutjat la invitació per a unir-se a {circle}",
    "You cancelled your request to join {circle}" : "Heu cancel·lat la sol·licitud per a unir-vos a {circle}",
    "{member} cancelled a request to join {circle}" : "{member} ha cancel·lat una sol·licitud per a unir-se a {circle}",
    "You have been removed from {circle} by {author}" : "{author} us ha suprimit del cercle {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} ha suprimit {member} del cercle {circle}",
    "You removed {external} from {circle}" : "Heu suprimit {external} del cercle {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} ha suprimit {external} del cercle {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Heu cancel·lat la invitació del membre {member} per a unir-vos a {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} ha cancel·lat la invitació per a unir-vos a {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} ha cancel·lat la invitació del membre {member} per a unir-se a {circle}",
    "You dismissed {member}'s request to join {circle}" : "Heu descartat la sol·licitud del membre {member} per a unir-se a {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "{author} ha descartat la sol·licitud per a unir-vos a {circle}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} ha descartat la sol·licitud del membre {member} per a unir-se a {circle}",
    "You invited {member} to join {circle}" : "Heu convidat {member} a unir-se a {circle}",
    "You have been invited to join {circle} by {author}" : "{author} us ha convidat a unir-vos a {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} ha convidat {member} a unir-se a {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "Heu canviat el nivell del membre {member} a {circle} a %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} ha canviat el vostre nivell a {circle} a %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} ha canviat el nivell del membre {member} a {circle} a %1$s",
    "You sent a request to join {circle}" : "Heu enviat una sol·licitud per a unir-vos a {circle}",
    "{member} sent a request to join {circle}" : "{member} ha enviat una sol·licitud per a unir-se a {circle}",
    "You are the new owner of {circle}" : "Ara teniu la propietat del cercle {circle}",
    "{member} is the new owner of {circle}" : "{member} ara té la propietat del cercle {circle}",
    "On events happening in a <strong>team</strong> of which you are a member" : "Quan es produeixin esdeveniments en un <strong>equip</strong> del qual sigueu membre",
    "Any important event in a <strong>team</strong> you are moderating" : "Quan es produeixi qualsevol esdeveniment important en un <strong>equip</strong> que modereu",
    "On global events happening in any <strong>team</strong>" : "Quan es produeixin esdeveniments globals en qualsevol <strong>equip</strong>",
    "Single" : "Individual",
    "Personal" : "Personal",
    "System" : "Sistema",
    "Visible" : "Visible",
    "Open" : "Obert",
    "Invite" : "Invitació",
    "Join request" : "Sol·licitud per a unir-s'hi",
    "Friends" : "Amics",
    "Password protected" : "Protegit amb contrasenya",
    "No Owner" : "Sense propietari",
    "Hidden" : "Ocult",
    "Backend" : "Rerefons",
    "Local" : "Local",
    "Root" : "Arrel",
    "Team invite" : "Invitació a l'equip",
    "Federated" : "Federat",
    "Mount point" : "Punt de muntatge",
    "Nextcloud Account" : "Compte del Nextcloud",
    "Nextcloud Group" : "Grup del Nextcloud",
    "Email address" : "Adreça electrònica",
    "Contact" : "Contacte",
    "Circle" : "Cercle",
    "Nextcloud App" : "Aplicació del Nextcloud",
    "Member" : "Membre",
    "Moderator" : "Moderació",
    "Admin" : "Administració",
    "Owner" : "Propietat",
    "%s shared »%s« with you." : "%s ha compartit «%s» amb vós.",
    "%s shared »%s« with \"%s\"." : "%s ha compartit «%s» amb «%s».",
    "%s on %s" : "%s a %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s ha compartit «%2$s» amb vós.\nJa hauríeu d'haver rebut un altre correu electrònic amb un enllaç per a accedir-hi.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s ha compartit «%2$s» amb vós. Ja hauríeu d'haver rebut un altre correu electrònic amb un enllaç per a accedir-hi.",
    "Password to access »%1$s« shared to you by %2$s" : "%2$s ha compartit amb vós la contrasenya per a accedir a «%1$s»",
    "Password to access »%s«" : "Contrasenya per a accedir a «%s»",
    "It is protected with the following password:" : "Està protegit amb la contrasenya següent:",
    "%1$s via %2$s" : "%1$s mitjançant %2$s",
    "Click the button below to open it." : "Feu clic en el botó següent per a obrir-lo.",
    "Open »%s«" : "Obre «%s»",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s ha compartit diversos fitxers amb vós.\nJa hauríeu d'haver rebut un altre correu electrònic amb un enllaç per a accedir-hi.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s ha compartit diversos fitxers amb vós. Ja hauríeu d'haver rebut un altre correu electrònic amb un enllaç per a accedir-hi.",
    "Password to access files shared to you by %1$s" : "Contrasenya per a accedir als fitxers que %1$s ha compartit amb vós",
    "Password to access files" : "Contrasenya per a accedir als fitxers",
    "%s shared multiple files with \"%s\"." : "%s ha compartit diversos fitxers amb «%s».",
    "%s shared multiple files with you." : "%s ha compartit diversos fitxers amb vós.",
    "Boot up" : "Engegada",
    "Nextcloud Initialization" : "Inicialització del Nextcloud",
    "Circles App Initialization" : "Inicialització de l'aplicació Cercles",
    "Fresh installation status" : "Estat d'instal·lació nou",
    "Building Local Database" : "S'està creant la base de dades local",
    "Testing Basic Circle Creation" : "S'està provant la creació d'un cercle bàsic",
    "Adding local users and moderators" : "S'estan afegint usuaris i moderadors locals",
    "Show all teams" : "Mostra tots els equips",
    "Create a new team" : "Crea un equip nou",
    "Files" : "Fitxers",
    "This feature is not available for personal circles" : "Aquesta característica no està disponible per als cercles personals",
    "The team is not federated" : "L'equip no està federat",
    "You cannot join this team" : "No us podeu unir a aquest equip",
    "This member is not a moderator" : "Aquest membre no té permisos de moderació",
    "Insufficient privileges" : "Privilegis insuficients",
    "This member does not exist" : "Aquest membre no existeix",
    "This member is the owner of the team" : "Aquest membre té la propietat de l'equip",
    "Level cannot be changed for this type of member" : "No es pot canviar el nivell per a aquest tipus de membre",
    "You are already a member of this circle" : "Ja sou membre d'aquest cercle",
    "You have been blocked from this circle" : "Se us ha blocat d'aquest cercle",
    "The account is already a member of this circle" : "El compte ja és membre d'aquest cercle",
    "The account has already been invited into this circle" : "El compte ja ha rebut una invitació per a aquest cercle",
    "%s (Team owned by %s)" : "%s (equip propietat de %s)",
    "You are now a member of the Team \"%2$s\"" : "Ara ets membre de l'equip \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "%1$s t'ha convidat a l'equip \"%2$s\"",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s va enviar una sol·licitud per ser membre de l'equip \"%2$s\"",
    "Accept" : "Accepta",
    "Refuse" : "Rebutja",
    "Leave the team" : "Deixa l'equip",
    "%s" : "%s",
    "Personal team" : "Equip personal",
    "%s owned by %s" : "%s propietat de %s",
    "You have no permission to create a new team" : "No teniu permís per a crear un equip nou",
    "%s shared a file with \"%s\"." : "%s ha compartit un fitxer amb «%s».",
    "%s shared a file with you." : "%s ha compartit un fitxer amb vós.",
    "Open %s" : "Obre %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s ha compartit contingut amb vós.\nJa hauríeu d'haver rebut un altre correu electrònic amb un enllaç per a accedir-hi.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s ha compartit contingut amb vós. Ja hauríeu d'haver rebut un altre correu electrònic amb un enllaç per a accedir-hi.",
    "Password to access content shared with you by %1$s" : "Contrasenya per a accedir al contingut que %1$s ha compartit amb vós",
    "Password to access content" : "Contrasenya per a accedir al contingut",
    "This item is already shared with this team" : "Aquest element ja està compartit amb aquest equip",
    "Bring cloud-users closer together." : "Acosteu els usuaris del núvol.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Els equips permeten que les persones creïn els seus propis grups de persones, companys i amics.\nQualsevol altra aplicació pot utilitzar aquests grups de persones per a compartir contingut.",
    "No files in here" : "No hi ha cap fitxer aquí",
    "No entries found in this folder" : "No s'ha trobat cap entrada en aquesta carpeta",
    "Name" : "Nom",
    "Size" : "Mida",
    "Modified" : "Data de modificació",
    "Teams' files" : "Fitxers dels equips",
    "Select team to filter by" : "Seleccioneu l'equip que voleu filtrar",
    "No teams found" : "No s'ha trobat cap equip",
    "Please select teams to filter by" : "Seleccioneu els equips que voleu filtrar",
    "No files found for the selected teams" : "No s'ha trobat cap fitxer per als equips seleccionats",
    "Shared to Circles" : "Compartits en cercles"
},
"nplurals=2; plural=(n != 1);");
